@@ -35,7 +35,7 @@ inline double powi(double base, int times)
 #define TAU 1e-12
 #define Malloc(type,n) (type *)malloc((n)*sizeof(type))
 #if 0
-void info(char *fmt,...)
+void info(const char *fmt,...)
 {
 	va_list ap;
 	va_start(ap,fmt);
@@ -47,7 +47,7 @@ void info_flush()
 	fflush(stdout);
 }
 #else
-void info(char *fmt,...) {}
+void info(const char *fmt,...) {}
 void info_flush() {}
 #endif
 
